@@ -31,9 +31,13 @@ def Print(val):
 def randomom(val):
     print(random.randint(val))
 
+
 def p1():
     print("1")
 
+def p2():
+    print("2")
+
 class htm2():
     class handDetector():
         def __init__(self, mode=False,maxHands=2,detectionCon=0.5,trackCon=0.5):
@@ -126,7 +130,7 @@ class htm2():
         pTime = 0
         cTime = 0
         cap = cv2.VideoCapture(0)
-        detector = handDetector()
+        detector = htm2.handDetector()
         while True:
             success, img = cap.read()
             img = detector.findHands(img)
@@ -785,7 +789,7 @@ class HandProjects():
         cap.set(4,720)
 
         xp, yp = 0,0
-        detector = htm.handDetector(detectionCon=0.65)
+        detector = htm2.handDetector(detectionCon=Confidence)
 
         brushThickness = BrushThickness
         eraserThickness = EraserThickness
